@@ -22,13 +22,19 @@
  * Author: Paolo Maggi 
  */
 
+#ifdef HAVE_CONFIG_H
+#include <config.h>
+#endif
+
 #include "bonobo-mdi.h"
 
 #include <bonobo/bonobo-i18n.h>
-#include <libgnome/gnome-marshal.h>
+#include <gedit-marshal.h>
 #include <bonobo/bonobo-dock-layout.h>
 #include <bonobo/bonobo-ui-util.h>
 
+#include "gedit-debug.h"
+
 #include <string.h>
 
 #define BONOBO_MDI_KEY "BonoboMDI"
@@ -177,48 +183,82 @@ bonobo_mdi_class_init (BonoboMDIClass *class)
 	object_class->destroy = bonobo_mdi_destroy;
 	gobject_class->finalize = bonobo_mdi_finalize;
 
-	mdi_signals[ADD_CHILD] = gtk_signal_new ("add_child",
-					GTK_RUN_LAST,
-					GTK_CLASS_TYPE (object_class),
-					GTK_SIGNAL_OFFSET (BonoboMDIClass, add_child),
-					gnome_marshal_BOOLEAN__OBJECT,
-					GTK_TYPE_BOOL, 1, BONOBO_TYPE_MDI_CHILD);
-	mdi_signals[REMOVE_CHILD] = gtk_signal_new ("remove_child",
-					GTK_RUN_LAST,
-					GTK_CLASS_TYPE (object_class),
-					GTK_SIGNAL_OFFSET (BonoboMDIClass, remove_child),
-					gnome_marshal_BOOLEAN__OBJECT,
-					GTK_TYPE_BOOL, 1, BONOBO_TYPE_MDI_CHILD);
-	mdi_signals[ADD_VIEW] = gtk_signal_new ("add_view",
-					GTK_RUN_LAST,
-					GTK_CLASS_TYPE (object_class),
-					GTK_SIGNAL_OFFSET (BonoboMDIClass, add_view),
-					gnome_marshal_BOOLEAN__OBJECT,
-					GTK_TYPE_BOOL, 1, GTK_TYPE_WIDGET);
-	mdi_signals[REMOVE_VIEW] = gtk_signal_new ("remove_view",
-					GTK_RUN_LAST,
-					GTK_CLASS_TYPE (object_class),
-					GTK_SIGNAL_OFFSET (BonoboMDIClass, remove_view),
-					gnome_marshal_BOOLEAN__OBJECT,
-					GTK_TYPE_BOOL, 1, GTK_TYPE_WIDGET);
-	mdi_signals[CHILD_CHANGED] = gtk_signal_new ("child_changed",
-					GTK_RUN_LAST,
-					GTK_CLASS_TYPE (object_class),
-					GTK_SIGNAL_OFFSET (BonoboMDIClass, child_changed),
-					gtk_marshal_VOID__OBJECT,
-					GTK_TYPE_NONE, 1, BONOBO_TYPE_MDI_CHILD);
-	mdi_signals[VIEW_CHANGED] = gtk_signal_new ("view_changed",
-					GTK_RUN_LAST,
-					GTK_CLASS_TYPE (object_class),
-					GTK_SIGNAL_OFFSET(BonoboMDIClass, view_changed),
-					gtk_marshal_VOID__OBJECT,
-					GTK_TYPE_NONE, 1, GTK_TYPE_WIDGET);
-	mdi_signals[TOP_WINDOW_CREATED] = gtk_signal_new ("top_window_created",
-					GTK_RUN_LAST,
-					GTK_CLASS_TYPE (object_class),
-					GTK_SIGNAL_OFFSET (BonoboMDIClass, top_window_created),
-					gtk_marshal_VOID__OBJECT,
-					GTK_TYPE_NONE, 1, BONOBO_TYPE_WINDOW);
+	mdi_signals[ADD_CHILD] = 
+		g_signal_new ("add_child",
+ 			      G_OBJECT_CLASS_TYPE (object_class),
+			      G_SIGNAL_RUN_LAST,
+			      G_STRUCT_OFFSET (BonoboMDIClass, add_child),
+			      NULL, NULL,
+			      gedit_marshal_BOOLEAN__OBJECT,
+			      G_TYPE_BOOLEAN, 
+			      1, 
+			      BONOBO_TYPE_MDI_CHILD);
+	
+	mdi_signals[REMOVE_CHILD] = 
+		g_signal_new ("remove_child",
+			      G_OBJECT_CLASS_TYPE (object_class),
+			      G_SIGNAL_RUN_LAST,
+			      G_STRUCT_OFFSET (BonoboMDIClass, remove_child),
+			      NULL, NULL,
+			      gedit_marshal_BOOLEAN__OBJECT,
+			      G_TYPE_BOOLEAN, 
+			      1, 
+			      BONOBO_TYPE_MDI_CHILD);
+	
+	mdi_signals[ADD_VIEW] = 
+		g_signal_new ("add_view",
+			      G_OBJECT_CLASS_TYPE (object_class),
+			      G_SIGNAL_RUN_LAST,
+			      G_STRUCT_OFFSET (BonoboMDIClass, add_view),
+			      NULL, NULL,			     
+			      gedit_marshal_BOOLEAN__OBJECT,
+			      G_TYPE_BOOLEAN, 
+			      1, 
+			      GTK_TYPE_WIDGET);
+	
+	mdi_signals[REMOVE_VIEW] = 
+		g_signal_new ("remove_view",
+			      G_OBJECT_CLASS_TYPE (object_class),
+			      G_SIGNAL_RUN_LAST,
+			      G_STRUCT_OFFSET (BonoboMDIClass, remove_view),
+			      NULL, NULL,
+			      gedit_marshal_BOOLEAN__OBJECT,
+			      G_TYPE_BOOLEAN, 
+			      1, 
+			      GTK_TYPE_WIDGET);
+
+	mdi_signals[CHILD_CHANGED] = 
+		g_signal_new ("child_changed",
+			      G_OBJECT_CLASS_TYPE (object_class),
+			      G_SIGNAL_RUN_LAST,
+			      G_STRUCT_OFFSET (BonoboMDIClass, child_changed),
+			      NULL, NULL,
+			      g_cclosure_marshal_VOID__OBJECT,
+			      G_TYPE_NONE, 
+			      1, 
+			      BONOBO_TYPE_MDI_CHILD);
+
+	mdi_signals[VIEW_CHANGED] = 
+		g_signal_new ("view_changed",
+			      G_OBJECT_CLASS_TYPE (object_class),
+			      G_SIGNAL_RUN_LAST,
+			      G_STRUCT_OFFSET(BonoboMDIClass, view_changed),
+			      NULL, NULL,
+			      g_cclosure_marshal_VOID__OBJECT,
+			      G_TYPE_NONE, 
+			      1, 
+			      GTK_TYPE_WIDGET);
+
+	mdi_signals[TOP_WINDOW_CREATED] = 
+		g_signal_new ("top_window_created",
+			      G_OBJECT_CLASS_TYPE (object_class),
+			      G_SIGNAL_RUN_LAST,
+			      G_STRUCT_OFFSET (BonoboMDIClass, top_window_created),
+			      NULL, NULL,
+			      g_cclosure_marshal_VOID__OBJECT,
+			      G_TYPE_NONE, 
+			      1, 
+			      BONOBO_TYPE_WINDOW);
 	
 	class->add_child 		= NULL;
 	class->remove_child 		= NULL;
@@ -291,7 +331,7 @@ bonobo_mdi_destroy (GtkObject *object)
 	   upon mdi creation. */
 	/*
 	if(G_OBJECT (object)->ref_count > 0 && !GTK_OBJECT_DESTROYED (object))
-		gtk_object_unref (object);
+		g_object_unref (G_OBJECT (object));
 	*/
 
 	if(GTK_OBJECT_CLASS (parent_class)->destroy)
@@ -310,7 +350,8 @@ bonobo_mdi_instance_init (BonoboMDI *mdi)
 	mdi->priv->tab_pos = gnome_preferences_get_mdi_tab_pos();
 	 */
 	mdi->priv->mode = BONOBO_MDI_NOTEBOOK;
-
+	mdi->priv->tab_pos = GTK_POS_TOP;
+		
 	mdi->priv->signal_id 		= 0;
 	mdi->priv->in_drag 		= FALSE;
 
@@ -332,6 +373,9 @@ bonobo_mdi_instance_init (BonoboMDI *mdi)
 	mdi->priv->verbs		= NULL;	
 	
 	mdi->priv->child_list_path 	= NULL;
+
+	g_object_ref (G_OBJECT (mdi));
+	gtk_object_sink (GTK_OBJECT (mdi));
 }
 
 
@@ -352,7 +396,7 @@ bonobo_mdi_new (const gchar *mdi_name, const gchar *title)
 {
 	BonoboMDI *mdi;
 	
-	mdi = gtk_type_new (BONOBO_TYPE_MDI);
+	mdi = g_object_new (BONOBO_TYPE_MDI, NULL);
   
 	mdi->priv->mdi_name = g_strdup (mdi_name);
 	mdi->priv->title    = g_strdup (title);
@@ -374,7 +418,10 @@ child_create_menus (BonoboMDIChild *child, GtkWidget *view)
 static GtkWidget *
 child_set_label (BonoboMDIChild *child, GtkWidget *label)
 {
-	return BONOBO_MDI_CHILD_GET_CLASS (child)->set_label (child, label, NULL);
+	GtkWidget *w;
+	w = BONOBO_MDI_CHILD_GET_CLASS (child)->set_label (child, label, NULL);
+	
+	return w;
 }
 
 static void 
@@ -396,7 +443,7 @@ child_list_activated_cb (BonoboUIComponent *uic, gpointer user_data, const gchar
 	BonoboMDIChild *child = BONOBO_MDI_CHILD (user_data);
 	g_return_if_fail (child != NULL);
 
-	mdi = BONOBO_MDI (gtk_object_get_data (GTK_OBJECT (child), BONOBO_MDI_KEY));
+	mdi = BONOBO_MDI (g_object_get_data (G_OBJECT (child), BONOBO_MDI_KEY));
 	g_return_if_fail (mdi != NULL);
 		
 	if (child && (child != mdi->priv->active_child)) 
@@ -458,7 +505,7 @@ child_list_menu_create (BonoboMDI *mdi, BonoboWindow *win)
 		return;
 	
 	ui_component = BONOBO_UI_COMPONENT (
-			gtk_object_get_data (GTK_OBJECT (win), UI_COMPONENT_KEY));
+			g_object_get_data (G_OBJECT (win), UI_COMPONENT_KEY));
 			
 	child = mdi->priv->children;
 	
@@ -521,7 +568,7 @@ child_list_menu_remove_item (BonoboMDI *mdi, BonoboMDIChild *child)
 		BonoboUIComponent *ui_component;
 		
 		ui_component = BONOBO_UI_COMPONENT (
-			gtk_object_get_data (GTK_OBJECT (win_node->data), UI_COMPONENT_KEY));
+			g_object_get_data (G_OBJECT (win_node->data), UI_COMPONENT_KEY));
 		
 		bonobo_ui_component_remove_verb (ui_component, verb_name);
 		bonobo_ui_component_rm (ui_component, path, NULL);
@@ -562,7 +609,7 @@ child_list_menu_add_item (BonoboMDI *mdi, BonoboMDIChild *child)
 		BonoboUIComponent *ui_component;
 		
 		ui_component = BONOBO_UI_COMPONENT (
-			gtk_object_get_data (GTK_OBJECT (win_node->data), UI_COMPONENT_KEY));
+			g_object_get_data (G_OBJECT (win_node->data), UI_COMPONENT_KEY));
 		
 
 		bonobo_ui_component_set_translate (ui_component, mdi->priv->child_list_path, xml, NULL);
@@ -590,7 +637,7 @@ book_motion (GtkWidget *widget, GdkEventMotion *e, gpointer data)
 	if (!drag_cursor)
 		drag_cursor = gdk_cursor_new (GDK_HAND2);
 
-	if (e->window == widget->window) 
+	if (e->window == GTK_NOTEBOOK (widget)->event_window) 
 	{
 		mdi->priv->in_drag = TRUE;
 		gtk_grab_add (widget);
@@ -600,7 +647,8 @@ book_motion (GtkWidget *widget, GdkEventMotion *e, gpointer data)
 						 drag_cursor, GDK_CURRENT_TIME);
 		if (mdi->priv->signal_id) 
 		{
-			gtk_signal_disconnect (GTK_OBJECT (widget), mdi->priv->signal_id);
+			g_signal_handler_disconnect (G_OBJECT (widget), 
+						     mdi->priv->signal_id);
 			mdi->priv->signal_id = 0;
 		}
 	}
@@ -615,10 +663,12 @@ book_button_press (GtkWidget *widget, GdkEventButton *e, gpointer data)
 
 	mdi = BONOBO_MDI (data);
 
-	if (e->button == 1 && e->window == widget->window)
-		mdi->priv->signal_id = gtk_signal_connect (GTK_OBJECT (widget), 
+	if ((e->button == 1) && (e->window == GTK_NOTEBOOK (widget)->event_window))
+		mdi->priv->signal_id = g_signal_connect (
+				G_OBJECT (widget), 
 				"motion_notify_event",
-				GTK_SIGNAL_FUNC (book_motion), mdi);
+				G_CALLBACK (book_motion), 
+				mdi);
 
 	return FALSE;
 }
@@ -633,17 +683,17 @@ book_button_release (GtkWidget *widget, GdkEventButton *e, gpointer data)
 	
 	if (mdi->priv->signal_id) 
 	{
-		gtk_signal_disconnect (GTK_OBJECT (widget), mdi->priv->signal_id);
+		g_signal_handler_disconnect (G_OBJECT (widget), mdi->priv->signal_id);
 		mdi->priv->signal_id = 0;
 	}
 
-	if (e->button == 1 && e->window == widget->window && mdi->priv->in_drag) 
-	{
+	if ((e->button == 1) && mdi->priv->in_drag) 
+	{	
 		GdkWindow *window;
 		GList *child;
 		BonoboWindow *win;
 		GtkWidget *view, *new_book;
-		GtkNotebook *old_book = GTK_NOTEBOOK(widget);
+		GtkNotebook *old_book = GTK_NOTEBOOK (widget);
 
 		mdi->priv->in_drag = FALSE;
 		gdk_pointer_ungrab (GDK_CURRENT_TIME);
@@ -682,6 +732,8 @@ book_button_release (GtkWidget *widget, GdkEventButton *e, gpointer data)
 					win = bonobo_mdi_get_window_from_view (view);
 					gdk_window_raise (GTK_WIDGET(win)->window);
 
+					mdi->priv->active_window = win;
+
 					cur_page = gtk_notebook_get_current_page (GTK_NOTEBOOK (old_book));
 
 					if (cur_page < 0) 
@@ -691,7 +743,17 @@ book_button_release (GtkWidget *widget, GdkEventButton *e, gpointer data)
 									GTK_WIDGET (old_book)));
 						mdi->priv->windows = g_list_remove(mdi->priv->windows, win);
 						gtk_widget_destroy (GTK_WIDGET(win));
-					}
+					}					
+										
+					g_signal_emit (G_OBJECT (mdi), 
+						       mdi_signals [CHILD_CHANGED], 
+						       0,
+						       NULL);
+
+					g_signal_emit (G_OBJECT (mdi), 
+						       mdi_signals [VIEW_CHANGED], 
+						       0,
+						       view);
 				}
 
 				return FALSE;
@@ -715,9 +777,9 @@ book_button_release (GtkWidget *widget, GdkEventButton *e, gpointer data)
 
 			width = view->allocation.width;
 			height = view->allocation.height;
-			
+		
 			gtk_container_remove (GTK_CONTAINER (old_book), view);
-				
+			
 			app_clone (mdi, win);
 				
 			new_book = book_create (mdi);
@@ -726,7 +788,7 @@ book_button_release (GtkWidget *widget, GdkEventButton *e, gpointer data)
 
 			gtk_window_set_position (GTK_WINDOW (mdi->priv->active_window), GTK_WIN_POS_MOUSE);
 	
-			gtk_widget_set_usize (view, width, height);
+			gtk_widget_set_size_request (view, width, height);
 
 			if (!GTK_WIDGET_VISIBLE (mdi->priv->active_window))
 				gtk_widget_show (GTK_WIDGET (mdi->priv->active_window));
@@ -740,7 +802,7 @@ static GtkWidget *
 book_create (BonoboMDI *mdi)
 {
 	GtkWidget *us;
-	
+
 	us = gtk_notebook_new ();
 
 	gtk_notebook_set_tab_pos (GTK_NOTEBOOK (us), mdi->priv->tab_pos);
@@ -751,13 +813,13 @@ book_create (BonoboMDI *mdi)
 	
 	gtk_widget_add_events (us, GDK_BUTTON1_MOTION_MASK);
 
-	gtk_signal_connect (GTK_OBJECT (us), "switch_page",
-			    GTK_SIGNAL_FUNC (book_switch_page), mdi);
+	g_signal_connect (G_OBJECT (us), "switch_page",
+			  G_CALLBACK (book_switch_page), mdi);
 
-	gtk_signal_connect (GTK_OBJECT (us), "button_press_event",
-			    GTK_SIGNAL_FUNC (book_button_press), mdi);
-	gtk_signal_connect (GTK_OBJECT (us), "button_release_event",
-			    GTK_SIGNAL_FUNC (book_button_release), mdi);
+	g_signal_connect (G_OBJECT (us), "button_press_event",
+			  G_CALLBACK (book_button_press), mdi);
+	g_signal_connect (G_OBJECT (us), "button_release_event",
+			  G_CALLBACK (book_button_release), mdi);
 
 	gtk_notebook_set_scrollable (GTK_NOTEBOOK (us), TRUE);
 	
@@ -859,14 +921,15 @@ app_clone(BonoboMDI *mdi, BonoboWindow *win)
 		if (dock != NULL)
 		{
 			layout = bonobo_dock_get_layout (dock);
+			if (layout)
 			layout_string = bonobo_dock_layout_create_string (layout);
-			gtk_object_unref (GTK_OBJECT (layout));
+			g_object_unref (G_OBJECT (layout));
 		}
 	}
 
-	app_create(mdi, layout_string);
+	app_create (mdi, layout_string);
 
-	if(layout_string)
+	if (layout_string)
 		g_free(layout_string);
 }
 
@@ -908,7 +971,7 @@ app_close_top (BonoboWindow *win, GdkEventAny *event, BonoboMDI *mdi)
 		else 
 		{
 			mdi->priv->windows = g_list_remove (mdi->priv->windows, win);
-			gtk_widget_destroy (GTK_WIDGET(win));
+			gtk_widget_destroy (GTK_WIDGET (win));
 		}
 	}
 	
@@ -969,8 +1032,12 @@ app_close_book (BonoboWindow *win, GdkEventAny *event, BonoboMDI *mdi)
 			if (node == NULL) 
 			{   
 				/* all the views reside in this BonoboWindow */
-				gtk_signal_emit(GTK_OBJECT(mdi), mdi_signals [REMOVE_CHILD],
-						child, &handler_ret);
+				g_signal_emit(G_OBJECT(mdi), 
+					      mdi_signals [REMOVE_CHILD],
+					      0,
+					      child, 
+					      &handler_ret);
+
 				if (handler_ret == FALSE) 
 				{
 					g_list_free (children);
@@ -1015,10 +1082,10 @@ static void app_set_view
 	
 
 	/* free previous child ui-info */
-	ui_info = gtk_object_get_data(GTK_OBJECT(app), GNOME_MDI_CHILD_MENU_INFO_KEY);
+	ui_info = g_object_get_data(G_OBJECT(app), GNOME_MDI_CHILD_MENU_INFO_KEY);
 	if(ui_info != NULL) {
 		free_ui_info_tree(ui_info);
-		gtk_object_set_data(GTK_OBJECT(app), GNOME_MDI_CHILD_MENU_INFO_KEY, NULL);
+		g_object_set_data(G_OBJECT(app), GNOME_MDI_CHILD_MENU_INFO_KEY, NULL);
 	}
 	ui_info = NULL;
 	
@@ -1026,7 +1093,7 @@ static void app_set_view
 		parent = gnome_app_find_menu_pos(app->menubar, mdi->child_menu_path, &pos);
 
 	/* remove old child-specific menus */
-	items = GPOINTER_TO_INT(gtk_object_get_data(GTK_OBJECT(app), GNOME_MDI_ITEM_COUNT_KEY));
+	items = GPOINTER_TO_INT(g_object_get_data(G_OBJECT(app), GNOME_MDI_ITEM_COUNT_KEY));
 	if(items > 0 && parent) {
 		GtkWidget *widget;
 
@@ -1078,7 +1145,7 @@ static void app_set_view
 			if( child->menu_template &&
 				( (ui_info = copy_ui_info_tree(child->menu_template)) != NULL) ) {
 				gnome_app_insert_menus_with_data(app, mdi->child_menu_path, ui_info, child);
-				gtk_object_set_data(GTK_OBJECT(app), GNOME_MDI_CHILD_MENU_INFO_KEY, ui_info);
+				g_object_set_data(G_OBJECT(app), GNOME_MDI_CHILD_MENU_INFO_KEY, ui_info);
 				items = count_ui_info_items(ui_info);
 			}
 			else {
@@ -1107,7 +1174,7 @@ static void app_set_view
 	else
 		gtk_window_set_title (GTK_WINDOW (win), mdi->priv->title);
 #if 0
-	gtk_object_set_data (GTK_OBJECT(app), GNOME_MDI_ITEM_COUNT_KEY, GINT_TO_POINTER(items));
+	g_object_set_data (G_OBJECT(app), GNOME_MDI_ITEM_COUNT_KEY, GINT_TO_POINTER(items));
 	
 	if (parent)
 		gtk_widget_queue_resize (parent);
@@ -1124,15 +1191,15 @@ app_destroy (BonoboWindow *win, BonoboMDI *mdi)
 #if 0
 	/* free stuff that got allocated for this BonoboWindow */
 
-	ui_info = gtk_object_get_data(GTK_OBJECT(app), GNOME_MDI_MENUBAR_INFO_KEY);
+	ui_info = g_object_get_data(G_OBJECT(app), GNOME_MDI_MENUBAR_INFO_KEY);
 	if(ui_info)
 		free_ui_info_tree(ui_info);
 	
-	ui_info = gtk_object_get_data(GTK_OBJECT(app), GNOME_MDI_TOOLBAR_INFO_KEY);
+	ui_info = g_object_get_data(G_OBJECT(app), GNOME_MDI_TOOLBAR_INFO_KEY);
 	if(ui_info)
 		free_ui_info_tree(ui_info);
 	
-	ui_info = gtk_object_get_data(GTK_OBJECT(app), GNOME_MDI_CHILD_MENU_INFO_KEY);
+	ui_info = g_object_get_data(G_OBJECT(app), GNOME_MDI_CHILD_MENU_INFO_KEY);
 	if(ui_info)
 		free_ui_info_tree(ui_info);
 #endif
@@ -1160,8 +1227,6 @@ static void app_create (BonoboMDI *mdi, gchar *layout_string)
 	gtk_window_set_wmclass (GTK_WINDOW (window), 
 			mdi->priv->mdi_name, mdi->priv->mdi_name);
   
-	gtk_window_set_policy (GTK_WINDOW (window), TRUE, TRUE, FALSE);
-  
 	mdi->priv->windows = g_list_append (mdi->priv->windows, window);
 
 	if ((mdi->priv->mode == BONOBO_MDI_TOPLEVEL) || (mdi->priv->mode == BONOBO_MDI_MODAL))
@@ -1170,17 +1235,18 @@ static void app_create (BonoboMDI *mdi, gchar *layout_string)
 		if (mdi->priv->mode == BONOBO_MDI_NOTEBOOK)
 			func = GTK_SIGNAL_FUNC (app_close_book);
 	
-	gtk_signal_connect (GTK_OBJECT (window), "delete_event", 
-			func, mdi);
-	gtk_signal_connect (GTK_OBJECT (window), "focus_in_event",
-			GTK_SIGNAL_FUNC(toplevel_focus), mdi);
-	gtk_signal_connect (GTK_OBJECT (window), "destroy",
-			GTK_SIGNAL_FUNC(app_destroy), mdi);
+	g_signal_connect (G_OBJECT (window), "delete_event", 
+			  func, mdi);
+	g_signal_connect (G_OBJECT (window), "focus_in_event",
+			  G_CALLBACK (toplevel_focus), mdi);
+	g_signal_connect (G_OBJECT (window), "destroy",
+			  G_CALLBACK (app_destroy), mdi);
 
 	/* Create Container: */
  	ui_container = bonobo_window_get_ui_container (bw);
 
-	config_path = g_strdup_printf ("/%s/UIConfig/kvps/", mdi->priv->mdi_name);
+	config_path = g_strdup_printf ("/%s/UIConfig/kvps", mdi->priv->mdi_name);
+
   	bonobo_ui_engine_config_set_path (bonobo_window_get_ui_engine (bw),
                                      config_path);
 	g_free (config_path);
@@ -1213,14 +1279,14 @@ static void app_create (BonoboMDI *mdi, gchar *layout_string)
 	mdi->priv->active_child = NULL;
 	mdi->priv->active_view = NULL;
 
-	gtk_object_set_data (GTK_OBJECT (bw), UI_COMPONENT_KEY, ui_component);
+	g_object_set_data (G_OBJECT (bw), UI_COMPONENT_KEY, ui_component);
 
-	gtk_signal_emit (GTK_OBJECT (mdi), mdi_signals [TOP_WINDOW_CREATED], window);
+	g_signal_emit (G_OBJECT (mdi), mdi_signals [TOP_WINDOW_CREATED], 0, window);
 
 	child_list_menu_create (mdi, bw);
 #if 0
 
-	if(layout_string && app->layout)
+	if (layout_string /*&& app->layout*/)
 		bonobo_dock_layout_parse_string(app->layout, layout_string);
 #endif
 }
@@ -1259,6 +1325,9 @@ set_active_view (BonoboMDI *mdi, GtkWidget *view)
 		mdi->priv->active_child = NULL;
 	}
 
+	if (view)
+		gtk_widget_grab_focus (GTK_WIDGET (view));
+
 	if (view == old_view)
 		return;
 	
@@ -1269,11 +1338,11 @@ set_active_view (BonoboMDI *mdi, GtkWidget *view)
 	}
 
 	mdi->priv->active_view = view;
-
+	
 	if (mdi->priv->active_child != old_child)
-		gtk_signal_emit (GTK_OBJECT (mdi), mdi_signals [CHILD_CHANGED], old_child);
+		g_signal_emit (G_OBJECT (mdi), mdi_signals [CHILD_CHANGED], 0, old_child);
 
-	gtk_signal_emit (GTK_OBJECT (mdi), mdi_signals [VIEW_CHANGED], old_view);
+	g_signal_emit (G_OBJECT (mdi), mdi_signals [VIEW_CHANGED], 0, old_view);
 }
 
 /**
@@ -1318,7 +1387,6 @@ bonobo_mdi_set_active_view (BonoboMDI *mdi, GtkWidget *view)
 	/* TODO: hmmm... I dont know how to give focus to the window, so that it
 	   would receive keyboard events */
 	gdk_window_raise (GTK_WIDGET (window)->window);
-	gtk_widget_grab_focus (GTK_WIDGET (window));
 
 	set_active_view (mdi, view);
 }
@@ -1365,7 +1433,7 @@ bonobo_mdi_add_view (BonoboMDI *mdi, BonoboMDIChild *child)
 			return TRUE;
 	}
 
-	gtk_signal_emit (GTK_OBJECT (mdi), mdi_signals [ADD_VIEW], view, &ret);
+	g_signal_emit (G_OBJECT (mdi), mdi_signals [ADD_VIEW], 0, view, &ret);
 
 	if (ret == FALSE) 
 	{
@@ -1379,12 +1447,7 @@ bonobo_mdi_add_view (BonoboMDI *mdi, BonoboMDIChild *child)
 		gtk_widget_show (GTK_WIDGET (mdi->priv->active_window));
 	}
 
-	/* this reference will compensate the view's unrefing
-	   when removed from its parent later, as we want it to
-	   stay valid until removed from the child with a call
-	   to bonobo_mdi_child_remove_view() */
-	gtk_widget_ref (view);
-
+	
 	if (!GTK_WIDGET_VISIBLE (view))
 		gtk_widget_show (view);
 
@@ -1416,9 +1479,17 @@ bonobo_mdi_add_view (BonoboMDI *mdi, BonoboMDIChild *child)
 
 				bonobo_window_set_contents (mdi->priv->active_window, view);
 				app_set_view (mdi, mdi->priv->active_window, view);
+
 			}
 
-	gtk_object_set_data (GTK_OBJECT (view), BONOBO_MDI_CHILD_KEY, child);
+	/* this reference will compensate the view's unrefing
+	   when removed from its parent later, as we want it to
+	   stay valid until removed from the child with a call
+	   to bonobo_mdi_child_remove_view() */
+	g_object_ref (G_OBJECT (view));
+	gtk_object_sink (GTK_OBJECT (view));
+
+	g_object_set_data (G_OBJECT (view), BONOBO_MDI_CHILD_KEY, child);
 	
 	return TRUE;
 }
@@ -1464,7 +1535,7 @@ bonobo_mdi_add_toplevel_view (BonoboMDI *mdi, BonoboMDIChild *child)
 	if (!view)
 		return FALSE;
 
-	gtk_signal_emit (GTK_OBJECT (mdi), mdi_signals [ADD_VIEW], view, &ret);
+	g_signal_emit (G_OBJECT (mdi), mdi_signals [ADD_VIEW], 0, view, &ret);
 
 	if (ret == FALSE) 
 	{
@@ -1511,7 +1582,7 @@ bonobo_mdi_add_toplevel_view (BonoboMDI *mdi, BonoboMDIChild *child)
 				app_set_view (mdi, mdi->priv->active_window, view);
 			}
 
-	gtk_object_set_data (GTK_OBJECT (view), BONOBO_MDI_CHILD_KEY, child);
+	g_object_set_data (G_OBJECT (view), BONOBO_MDI_CHILD_KEY, child);
 	
 	return TRUE;
 }
@@ -1538,6 +1609,8 @@ bonobo_mdi_remove_view (BonoboMDI *mdi, GtkWidget *view, gint force)
 	BonoboWindow *window;
 	BonoboMDIChild *child;
 	gint ret = TRUE;
+
+	gedit_debug (DEBUG_MDI, "");
 	
 	g_return_val_if_fail (mdi != NULL, FALSE);
 	g_return_val_if_fail (BONOBO_IS_MDI (mdi), FALSE);
@@ -1545,7 +1618,7 @@ bonobo_mdi_remove_view (BonoboMDI *mdi, GtkWidget *view, gint force)
 	g_return_val_if_fail (GTK_IS_WIDGET (view), FALSE);
 
 	if (!force)
-		gtk_signal_emit (GTK_OBJECT (mdi), mdi_signals [REMOVE_VIEW], view, &ret);
+		g_signal_emit (G_OBJECT (mdi), mdi_signals [REMOVE_VIEW], 0, view, &ret);
 
 	if (ret == FALSE)
 		return FALSE;
@@ -1559,8 +1632,12 @@ bonobo_mdi_remove_view (BonoboMDI *mdi, GtkWidget *view, gint force)
 
 	window = bonobo_mdi_get_window_from_view (view);
 
+	gedit_debug (DEBUG_MDI, "BU");
+
 	gtk_container_remove (GTK_CONTAINER (parent), view);
 
+	gedit_debug (DEBUG_MDI, "AU");
+
 	if (view == mdi->priv->active_view)
 	   mdi->priv->active_view = NULL;
 
@@ -1618,6 +1695,8 @@ bonobo_mdi_remove_view (BonoboMDI *mdi, GtkWidget *view, gint force)
 	if(mdi->priv->mode != BONOBO_MDI_MODAL)
 		bonobo_mdi_child_remove_view (child, view);
 
+	gedit_debug (DEBUG_MDI, "END");
+
 	return TRUE;
 }
 
@@ -1653,7 +1732,7 @@ bonobo_mdi_add_child (BonoboMDI *mdi, BonoboMDIChild *child)
 	g_return_val_if_fail (child != NULL, FALSE);
 	g_return_val_if_fail (BONOBO_IS_MDI_CHILD (child), FALSE);
 
-	gtk_signal_emit (GTK_OBJECT (mdi), mdi_signals [ADD_CHILD], child, &ret);
+	g_signal_emit (G_OBJECT (mdi), mdi_signals [ADD_CHILD], 0, child, &ret);
 
 	if (ret == FALSE)
 		return FALSE;
@@ -1662,12 +1741,12 @@ bonobo_mdi_add_child (BonoboMDI *mdi, BonoboMDIChild *child)
 
 	mdi->priv->children = g_list_append (mdi->priv->children, child);
 
-	gtk_signal_connect (GTK_OBJECT (child), "name_changed",
-			GTK_SIGNAL_FUNC (child_name_changed), mdi);
+	g_signal_connect (G_OBJECT (child), "name_changed",
+			  G_CALLBACK (child_name_changed), mdi);
 
 	child_list_menu_add_item (mdi, child);
 
-	gtk_object_set_data (GTK_OBJECT (child), BONOBO_MDI_KEY, mdi);
+	g_object_set_data (G_OBJECT (child), BONOBO_MDI_KEY, mdi);
 
 	return TRUE;
 }
@@ -1694,6 +1773,8 @@ bonobo_mdi_remove_child (BonoboMDI *mdi, BonoboMDIChild *child, gint force)
 	GList *view_node;
 	GtkWidget *view;
 
+	gedit_debug (DEBUG_MDI, "");
+	
 	g_return_val_if_fail (mdi != NULL, FALSE);
 	g_return_val_if_fail (BONOBO_IS_MDI (mdi), FALSE);
 	g_return_val_if_fail (child != NULL, FALSE);
@@ -1701,8 +1782,9 @@ bonobo_mdi_remove_child (BonoboMDI *mdi, BonoboMDIChild *child, gint force)
 
 	/* if force is set to TRUE, don't call the remove_child handler (ie there is no way for the
 	   user to stop removal of the child) */
+
 	if (!force)
-		gtk_signal_emit (GTK_OBJECT (mdi), mdi_signals [REMOVE_CHILD], child, &ret);
+		g_signal_emit (G_OBJECT (mdi), mdi_signals [REMOVE_CHILD], 0, child, &ret);
 
 	if (ret == FALSE)
 		return FALSE;
@@ -1718,6 +1800,7 @@ bonobo_mdi_remove_child (BonoboMDI *mdi, BonoboMDIChild *child, gint force)
 
 	mdi->priv->children = g_list_remove (mdi->priv->children, child);
 
+
 	child_list_menu_remove_item (mdi, child);
 
 	if (child == mdi->priv->active_child)
@@ -1725,10 +1808,12 @@ bonobo_mdi_remove_child (BonoboMDI *mdi, BonoboMDIChild *child, gint force)
 
 	bonobo_mdi_child_set_parent (child, NULL);
 
-	gtk_signal_disconnect_by_func (GTK_OBJECT (child), 
+	g_signal_handlers_disconnect_by_func (GTK_OBJECT (child), 
 			GTK_SIGNAL_FUNC (child_name_changed), mdi);
 
-	gtk_object_unref (GTK_OBJECT (child));
+
+	g_object_unref (G_OBJECT (child));
+
 
 	if (mdi->priv->mode == BONOBO_MDI_MODAL && mdi->priv->children) 
 	{
@@ -1779,8 +1864,11 @@ bonobo_mdi_remove_all (BonoboMDI *mdi, gint force)
 		child_node = mdi->priv->children;
 		while (child_node) 
 		{
-			gtk_signal_emit (GTK_OBJECT(mdi), mdi_signals [REMOVE_CHILD],
-				child_node->data, &handler_ret);
+			g_signal_emit (G_OBJECT(mdi), 
+				       mdi_signals [REMOVE_CHILD],
+				       0,
+				       child_node->data, 
+				       &handler_ret);
 
 			/* if any of the children may not be removed, none will be */
 			if (handler_ret == FALSE)
@@ -1878,12 +1966,19 @@ bonobo_mdi_update_child (BonoboMDI *mdi, BonoboMDIChild *child)
 		else 
 			if(mdi->priv->mode == BONOBO_MDI_NOTEBOOK) 
 			{
+				/*
 				GtkWidget *tab_label;
 
 				tab_label = gtk_notebook_get_tab_label
 					(GTK_NOTEBOOK (view->parent), view);
+					
 				if (tab_label != NULL)
-					title = child_set_label (child, tab_label);
+				{*/
+					title = child_set_label (child, NULL);
+					gtk_notebook_set_tab_label (GTK_NOTEBOOK (view->parent), 
+							view, title);
+				
+				/*}*/
 			}
 		
 		view_node = g_list_next (view_node);
@@ -1906,7 +2001,7 @@ bonobo_mdi_update_child (BonoboMDI *mdi, BonoboMDIChild *child)
 		BonoboUIComponent *ui_component;
 		
 		ui_component = BONOBO_UI_COMPONENT (
-			gtk_object_get_data (GTK_OBJECT (win_node->data), UI_COMPONENT_KEY));
+			g_object_get_data (G_OBJECT (win_node->data), UI_COMPONENT_KEY));
 
 		bonobo_ui_component_set_prop (ui_component, path, "label", escaped_name, NULL);
 		bonobo_ui_component_set_prop (ui_component, path, "tip", tip, NULL);
@@ -2051,20 +2146,27 @@ bonobo_mdi_set_mode (BonoboMDI *mdi, BonoboMDIMode mode)
 		*/
 		if ((mdi->priv->mode == BONOBO_MDI_TOPLEVEL) || 
 		    (mdi->priv->mode == BONOBO_MDI_MODAL))
-			gtk_signal_disconnect_by_func (GTK_OBJECT (mdi->priv->active_window),
-						GTK_SIGNAL_FUNC(app_close_top), mdi);
+			g_signal_handlers_disconnect_by_func (
+					G_OBJECT (mdi->priv->active_window),
+					G_CALLBACK (app_close_top), mdi);
 		else 
 			if(mdi->priv->mode == BONOBO_MDI_NOTEBOOK)
-				gtk_signal_disconnect_by_func (GTK_OBJECT (mdi->priv->active_window),
-							GTK_SIGNAL_FUNC (app_close_book), mdi);
+				g_signal_handlers_disconnect_by_func (
+						G_OBJECT (mdi->priv->active_window),
+						G_CALLBACK (app_close_book), mdi);
 
 		if ((mode == BONOBO_MDI_TOPLEVEL) || (mode == BONOBO_MDI_MODAL))
-			gtk_signal_connect (GTK_OBJECT (mdi->priv->active_window), "delete_event",
-					GTK_SIGNAL_FUNC (app_close_top), mdi);
+			g_signal_connect (G_OBJECT (mdi->priv->active_window), 
+					  "delete_event",
+					  G_CALLBACK (app_close_top), 
+					  mdi);
 		else 
 			if(mode == BONOBO_MDI_NOTEBOOK)
-				gtk_signal_connect (GTK_OBJECT (mdi->priv->active_window), "delete_event",
-							   GTK_SIGNAL_FUNC (app_close_book), mdi);
+				g_signal_connect (
+					G_OBJECT (mdi->priv->active_window), 
+					"delete_event",
+					G_CALLBACK (app_close_book), 
+					mdi);
 
 		mdi->priv->windows = g_list_append (NULL, mdi->priv->active_window);
 
@@ -2086,7 +2188,7 @@ bonobo_mdi_set_mode (BonoboMDI *mdi, BonoboMDIMode mode)
 			view = GTK_WIDGET(view_node->data);
 
 			if(width != 0)
-				gtk_widget_set_usize (view, width, height);
+				gtk_widget_set_size_request (view, width, height);
 
 			if(mdi->priv->mode == BONOBO_MDI_NOTEBOOK)
 				book_add_view (GTK_NOTEBOOK (
@@ -2295,7 +2397,7 @@ bonobo_mdi_unregister (BonoboMDI *mdi, GtkObject *object)
 BonoboMDIChild *
 bonobo_mdi_get_child_from_view (GtkWidget *view)
 {
-	return BONOBO_MDI_CHILD (gtk_object_get_data (GTK_OBJECT(view), BONOBO_MDI_CHILD_KEY));
+	return BONOBO_MDI_CHILD (g_object_get_data (G_OBJECT(view), BONOBO_MDI_CHILD_KEY));
 }
 
 /**
@@ -2368,11 +2470,11 @@ bonobo_mdi_construct (BonoboMDI *mdi, gchar* name, gchar* title, GtkPositionType
 	g_return_if_fail (mdi->priv->mdi_name == NULL);
 	g_return_if_fail (mdi->priv->title == NULL);
 
-	if (name != NULL)
-		mdi->priv->mdi_name = g_strdup (name);
+	g_return_if_fail (name != NULL);
+	g_return_if_fail (title != NULL);
 
-	if (title != NULL)
-		mdi->priv->title = g_strdup (title);
+	mdi->priv->mdi_name = g_strdup (name);
+	mdi->priv->title = g_strdup (title);
 
 	mdi->priv->tab_pos = tab_pos;
 }
@@ -2399,5 +2501,5 @@ BonoboUIComponent*
 bonobo_mdi_get_ui_component_from_window (BonoboWindow* win)
 {
 	return BONOBO_UI_COMPONENT (
-			gtk_object_get_data (GTK_OBJECT (win), UI_COMPONENT_KEY));
+			g_object_get_data (G_OBJECT (win), UI_COMPONENT_KEY));
 }
