@@ -27,6 +27,8 @@
  * See the ChangeLog files for a list of changes. 
  */
 
+#include <string.h>
+
 #include <glade/glade-xml.h>
 #include <libgnome/libgnome.h>
 
@@ -219,11 +221,11 @@ dialog_replace_get_dialog (void)
 	gtk_dialog_set_default_response (GTK_DIALOG (dialog->dialog),
 					 GEDIT_RESPONSE_FIND);
 
-	gtk_signal_connect(GTK_OBJECT (dialog->dialog), "destroy",
-			   GTK_SIGNAL_FUNC (dialog_destroyed), &dialog);
+	g_signal_connect(G_OBJECT (dialog->dialog), "destroy",
+			 G_CALLBACK (dialog_destroyed), &dialog);
 
-	gtk_signal_connect(GTK_OBJECT (dialog->dialog), "response",
-			   GTK_SIGNAL_FUNC (dialog_replace_response_handler), dialog);
+	g_signal_connect(G_OBJECT (dialog->dialog), "response",
+			 G_CALLBACK (dialog_replace_response_handler), dialog);
 
 	g_object_unref (G_OBJECT (gui));
 
@@ -306,11 +308,11 @@ dialog_find_get_dialog (void)
 	gtk_dialog_set_default_response (GTK_DIALOG (dialog->dialog),
 					 GEDIT_RESPONSE_FIND);
 
-	gtk_signal_connect(GTK_OBJECT (dialog->dialog), "destroy",
-			   GTK_SIGNAL_FUNC (dialog_destroyed), &dialog);
+	g_signal_connect(G_OBJECT (dialog->dialog), "destroy",
+			 G_CALLBACK (dialog_destroyed), &dialog);
 
-	gtk_signal_connect(GTK_OBJECT (dialog->dialog), "response",
-			   GTK_SIGNAL_FUNC (dialog_find_response_handler), dialog);
+	g_signal_connect(G_OBJECT (dialog->dialog), "response",
+			 G_CALLBACK (dialog_find_response_handler), dialog);
 
 	g_object_unref (G_OBJECT (gui));
 
@@ -323,7 +325,6 @@ void
 gedit_dialog_find (void)
 {
 	GeditDialogFind *dialog;
-	gint response;
 	GeditMDIChild *active_child;
 	GeditDocument *doc;
 	gchar* last_searched_text;
@@ -366,7 +367,6 @@ void
 gedit_dialog_replace (void)
 {
 	GeditDialogReplace *dialog;
-	gint response;
 	GeditMDIChild *active_child;
 	GeditDocument *doc;
 	gchar* last_searched_text;
@@ -570,7 +570,6 @@ replace_dlg_replace_button_pressed (GeditDialogReplace *dialog)
 	const gchar* search_string = NULL;
 	const gchar* replace_string = NULL;
 	gchar* selected_text = NULL;
-	gboolean from_cursor;
 	gboolean case_sensitive;
 
 	gedit_debug (DEBUG_SEARCH, "");
@@ -658,7 +657,6 @@ replace_dlg_replace_all_button_pressed (GeditDialogReplace *dialog)
 	GeditDocument *doc;
 	const gchar* search_string = NULL;
 	const gchar* replace_string = NULL;
-	gboolean from_cursor;
 	gboolean case_sensitive;
 	gint replaced_items;
 	GtkWidget *message_dlg;
