@@ -5,6 +5,7 @@
  *
  * Copyright (C) 1998, 1999 Alex Roberts, Evan Lawrence
  * Copyright (C) 2000, 2001 Chema Celorio, Paolo Maggi 
+ * Copyright (C) 2002  Paolo Maggi 
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -23,7 +24,7 @@
  */
  
 /*
- * Modified by the gedit Team, 1998-2001. See the AUTHORS file for a 
+ * Modified by the gedit Team, 1998-2002. See the AUTHORS file for a 
  * list of people on the gedit Team.  
  * See the ChangeLog files for a list of changes. 
  */
@@ -31,15 +32,9 @@
 #ifndef __GEDIT_DIALOGS_H__
 #define __GEDIT_DIALOGS_H__
 
-/*
-void gedit_dialog_about     (void);
-*/
+#include <gtk/gtkwindow.h>
+
 void gedit_dialog_goto_line (void);
-/*
-void gedit_dialog_replace   (gboolean replace);
-void gedit_find_again       (void);
-void gedit_dialog_prefs     (void);
-*/
 void gedit_dialog_find 	    (void);
 void gedit_dialog_replace   (void);
 
@@ -47,10 +42,8 @@ void gedit_dialog_open_uri  (void);
 
 void gedit_dialog_plugin_manager (void);
 
-/*
-gchar * gedit_plugin_program_location_dialog (gchar *program_name, gchar *plugin_name);
-
-void gedit_plugin_manager_create (GtkWidget *widget, gpointer data);
-*/
+gchar *gedit_plugin_program_location_dialog (gchar *program_name, 
+					     gchar *plugin_name, 
+					     GtkWindow *parent);
 
 #endif /* __GEDIT_DIALOGS_H__ */
