@@ -30,7 +30,6 @@
 #include <glade/glade-xml.h>
 #include <libgnomeui/libgnomeui.h>
 #include <libgnome/gnome-i18n.h>
-#include <libgnome/gnome-help.h>
 
 #include "gedit-dialogs.h"
 #include "gedit-debug.h"
@@ -43,7 +42,7 @@ static void error_dialog (const gchar* str, GtkWindow *parent);
  * of program_name
  */
 gchar *
-gedit_plugin_program_location_dialog (const gchar *program_name, const gchar *plugin_name,
+gedit_plugin_program_location_dialog (gchar *program_name, gchar *plugin_name,
 		GtkWindow *parent)
 {
 	GladeXML *gui;
@@ -71,7 +70,7 @@ gedit_plugin_program_location_dialog (const gchar *program_name, const gchar *pl
 		return NULL;
 	}
 
-	dialog = gtk_dialog_new_with_buttons (_("Set program location..."),
+	dialog = gtk_dialog_new_with_buttons (_("Set program location ..."),
 					      parent,
 					      GTK_DIALOG_MODAL | GTK_DIALOG_DESTROY_WITH_PARENT,
 					      GTK_STOCK_CANCEL,
@@ -93,8 +92,8 @@ gedit_plugin_program_location_dialog (const gchar *program_name, const gchar *pl
 
 	if (!content || !program_location_entry || !label || !logo)
 	{
-		g_warning (_("Could not find the required widgets inside %s."),
-			     "program-location-dialog.glade2");
+		g_warning (_("Could not find the required widgets inside "
+			     "program-location-dialog.glade2.\n"));
 		return NULL;
 	}
 	gtk_label_set_use_markup (GTK_LABEL (label), TRUE);
@@ -132,8 +131,6 @@ gedit_plugin_program_location_dialog (const gchar *program_name, const gchar *pl
 
 	do
 	{
-		GError *error = NULL;
-		
 		program_location = NULL;
 
 		ret = gtk_dialog_run (GTK_DIALOG (dialog));	
@@ -154,15 +151,7 @@ gedit_plugin_program_location_dialog (const gchar *program_name, const gchar *pl
 				break;
 				
 			case GTK_RESPONSE_HELP:
-				gnome_help_display ("gedit.xml", "gedit-use-plugins", &error);
-	
-				if (error != NULL)
-				{
-					g_warning (error->message);
-	
-					g_error_free (error);
-				}
-
+				/* FIXME */
 				break;
 
 			default:
