@@ -71,9 +71,9 @@ struct _GeditPreferencesDialogPrivate
 
 	GtkTreeModel *categories_tree_model;
 
+#if 0
 	/* Toolbar page */
-	GtkWidget	*toolbar_show_radiobutton;
-	GtkWidget	*toolbar_hide_radiobutton;
+	GtkWidget	*toolbar_show_checkbutton;
 	
 	GtkWidget	*toolbar_button_frame;
 	GtkWidget	*toolbar_system_radiobutton;
@@ -83,10 +83,10 @@ struct _GeditPreferencesDialogPrivate
 	GtkWidget	*toolbar_tooltips_checkbutton;
 
 	/* Statusbar page */
-	GtkWidget	*statusbar_show_radiobutton;
-	GtkWidget	*statusbar_hide_radiobutton;
+	GtkWidget	*statusbar_show_checkbutton;
 	GtkWidget	*statusbar_cursor_position_checkbutton;
 	GtkWidget	*statusbar_overwrite_mode_checkbutton;
+#endif
 
 #ifdef DEBUG_MDI_PREFS	
 	/*MDI page */
@@ -162,11 +162,14 @@ static GtkTreeModel* gedit_preferences_dialog_create_categories_tree_model ();
 
 static void gedit_preferences_dialog_categories_tree_selection_cb (GtkTreeSelection *selection, 
 							GeditPreferencesDialog *dlg);
-
+#if 0
 static gboolean gedit_preferences_dialog_setup_toolbar_page (GeditPreferencesDialog *dlg, GladeXML *gui);
-static void gedit_preferences_dialog_toolbar_show_radiobutton_toggled (GtkToggleButton *show_button,
+static void gedit_preferences_dialog_toolbar_show_checkbutton_toggled (GtkToggleButton *show_button,
 							 GeditPreferencesDialog *dlg);
 static gboolean gedit_preferences_dialog_setup_statusbar_page (GeditPreferencesDialog *dlg, GladeXML *gui);
+static void gedit_preferences_dialog_statusbar_show_checkbutton_toggled (GtkToggleButton *show_button,
+							 GeditPreferencesDialog *dlg);
+#endif
 
 #ifdef DEBUG_MDI_PREFS
 static gboolean gedit_preferences_dialog_setup_mdi_page (GeditPreferencesDialog *dlg, GladeXML *gui);
@@ -191,7 +194,7 @@ static gboolean gedit_preferences_dialog_setup_line_numbers_page (GeditPreferenc
 
 
 static GtkDialogClass* parent_class = NULL;
-
+#if 0
 static CategoriesTreeItem user_interface [] =
 {
 	{_("Toolbar"), NULL, TOOLBAR_SETTINGS},
@@ -203,6 +206,7 @@ static CategoriesTreeItem user_interface [] =
 
 	{ NULL }
 };
+#endif
 
 static CategoriesTreeItem editor_behavior [] =
 {
@@ -230,7 +234,9 @@ static CategoriesTreeItem toplevel [] =
 {
 	{_("Editor"), editor_behavior, LOGO},
 	{_("Print"), print, LOGO},
+#if 0
 	{_("User interface"), user_interface, LOGO},
+#endif
 	{ NULL }
 };
 
@@ -281,14 +287,32 @@ gedit_preferences_dialog_init (GeditPreferencesDialog *dlg)
 	GtkWidget *hbox;
 	GtkWidget *r;
        	GtkWidget *l;
+	GtkWidget *ct;
+	GtkWidget *label;
 	
 	gedit_debug (DEBUG_PREFS, "");
 
 	dlg->priv = g_new0 (GeditPreferencesDialogPrivate, 1);
 
+	gedit_preferences_dialog_add_buttons (dlg);	
+	
 	hbox = gtk_hbox_new (FALSE, 12);
+	
 	gtk_container_set_border_width (GTK_CONTAINER (hbox), 5);
-	r = gedit_preferences_dialog_create_categories_tree (dlg);
+	
+	r = gtk_vbox_new (FALSE, 0);
+	
+	label = gtk_label_new_with_mnemonic (_("Cat_egories:"));
+	gtk_label_set_justify (GTK_LABEL (label), GTK_JUSTIFY_LEFT);
+	g_object_set (G_OBJECT (label), "xalign", 0.0, NULL);
+
+	ct = gedit_preferences_dialog_create_categories_tree (dlg);
+
+	gtk_label_set_mnemonic_widget (GTK_LABEL (label), dlg->priv->categories_tree);
+		
+	gtk_box_pack_start (GTK_BOX (r), label, FALSE, FALSE, 6);
+	gtk_box_pack_start (GTK_BOX (r), ct, TRUE, TRUE, 0);
+
 	l = gedit_preferences_dialog_create_notebook (dlg);
 
 	gtk_box_pack_start (GTK_BOX (hbox), r, FALSE, FALSE, 0);
@@ -297,10 +321,8 @@ gedit_preferences_dialog_init (GeditPreferencesDialog *dlg)
 
 	gtk_box_pack_start (GTK_BOX (GTK_DIALOG (dlg)->vbox), hbox,
 			FALSE, FALSE, 0);
-
-	gtk_widget_show_all (hbox);
-
-	gedit_preferences_dialog_add_buttons (dlg);	
+	
+	gtk_widget_show_all (GTK_DIALOG (dlg)->vbox);	
 
 	gtk_window_set_modal (GTK_WINDOW (dlg), TRUE);
 
@@ -323,6 +345,8 @@ gedit_preferences_dialog_finalize (GObject *object)
 	g_return_if_fail (GEDIT_IS_PREFERENCES_DIALOG (dlg));
 	g_return_if_fail (dlg->priv != NULL);
 
+	g_object_unref (G_OBJECT (dlg->priv->categories_tree_model));
+
 	G_OBJECT_CLASS (parent_class)->finalize (object);
 
 	g_free (dlg->priv);
@@ -395,7 +419,7 @@ gedit_preferences_dialog_create_categories_tree_model ()
 		}
       
 		category++;
-	}
+	}	
 
 	gedit_debug (DEBUG_PREFS, "Done");
 
@@ -438,6 +462,7 @@ gedit_preferences_dialog_create_categories_tree (GeditPreferencesDialog *dlg)
 	GtkTreeSelection *selection;
 	GtkTreeViewColumn *column;
  	gint col_offset;
+	GtkTreeIter iter;
 	
 	gedit_debug (DEBUG_PREFS, "");
 
@@ -453,10 +478,13 @@ gedit_preferences_dialog_create_categories_tree (GeditPreferencesDialog *dlg)
 	model = gedit_preferences_dialog_create_categories_tree_model ();
 	
 	treeview = gtk_tree_view_new_with_model (model);
-/*
-	gtk_tree_view_set_rules_hint (GTK_TREE_VIEW (treeview), TRUE);
-*/
+	
 	selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (treeview));
+	g_return_val_if_fail (selection != NULL, NULL);
+
+	if (gtk_tree_model_get_iter_root (model, &iter))
+		gtk_tree_selection_select_iter (selection, &iter);
+	
 	gtk_tree_selection_set_mode (selection,
 				   GTK_SELECTION_SINGLE);
 
@@ -481,6 +509,8 @@ gedit_preferences_dialog_create_categories_tree (GeditPreferencesDialog *dlg)
       	g_signal_connect (G_OBJECT (treeview), "realize", 
 			G_CALLBACK (gtk_tree_view_expand_all), NULL);
 
+	gtk_tree_view_set_headers_visible (GTK_TREE_VIEW (treeview), FALSE);
+	
 	dlg->priv->categories_tree = treeview;
 	dlg->priv->categories_tree_model = model;
 	
@@ -510,9 +540,10 @@ gedit_preferences_dialog_create_notebook (GeditPreferencesDialog *dlg)
 		    ("Could not find the required widgets inside gedit-preferences.glade2.\n");
 		return NULL;
 	}
-
+#if 0
 	gedit_preferences_dialog_setup_toolbar_page (dlg, gui);
 	gedit_preferences_dialog_setup_statusbar_page (dlg, gui);
+#endif
 #ifdef DEBUG_MDI_PREFS
 	gedit_preferences_dialog_setup_mdi_page (dlg, gui);
 #endif
@@ -546,14 +577,13 @@ gedit_preferences_dialog_new (GtkWindow *parent)
 	
 	return dlg;
 }
-
+#if 0
 static gboolean 
 gedit_preferences_dialog_setup_toolbar_page (GeditPreferencesDialog *dlg, GladeXML *gui)
 {
 	gedit_debug (DEBUG_PREFS, "");
 
-	dlg->priv->toolbar_show_radiobutton = glade_xml_get_widget (gui, "toolbar_show_radiobutton");
-	dlg->priv->toolbar_hide_radiobutton = glade_xml_get_widget (gui, "toolbar_hide_radiobutton");
+	dlg->priv->toolbar_show_checkbutton = glade_xml_get_widget (gui, "toolbar_show_checkbutton");
 	
 	dlg->priv->toolbar_button_frame = glade_xml_get_widget (gui, "toolbar_button_frame");
 	dlg->priv->toolbar_system_radiobutton = glade_xml_get_widget (gui, "toolbar_system_radiobutton");
@@ -562,8 +592,7 @@ gedit_preferences_dialog_setup_toolbar_page (GeditPreferencesDialog *dlg, GladeX
 	
 	dlg->priv->toolbar_tooltips_checkbutton = glade_xml_get_widget (gui, "toolbar_tooltips_checkbutton");
 
-	g_return_val_if_fail (dlg->priv->toolbar_show_radiobutton != NULL, FALSE);
-	g_return_val_if_fail (dlg->priv->toolbar_hide_radiobutton != NULL, FALSE);
+	g_return_val_if_fail (dlg->priv->toolbar_show_checkbutton != NULL, FALSE);
 	
 	g_return_val_if_fail (dlg->priv->toolbar_button_frame != NULL, FALSE);
 	g_return_val_if_fail (dlg->priv->toolbar_system_radiobutton != NULL, FALSE);
@@ -572,16 +601,11 @@ gedit_preferences_dialog_setup_toolbar_page (GeditPreferencesDialog *dlg, GladeX
 	
 	g_return_val_if_fail (dlg->priv->toolbar_tooltips_checkbutton != NULL, FALSE);
 
-	g_signal_connect (G_OBJECT (dlg->priv->toolbar_show_radiobutton), "toggled", 
-			G_CALLBACK (gedit_preferences_dialog_toolbar_show_radiobutton_toggled), dlg);
+	g_signal_connect (G_OBJECT (dlg->priv->toolbar_show_checkbutton), "toggled", 
+			G_CALLBACK (gedit_preferences_dialog_toolbar_show_checkbutton_toggled), dlg);
 
-
-	if (gedit_settings->toolbar_visible)
-		gtk_toggle_button_set_active (
-			GTK_TOGGLE_BUTTON (dlg->priv->toolbar_show_radiobutton), TRUE);
-	else
-		gtk_toggle_button_set_active (
-			GTK_TOGGLE_BUTTON (dlg->priv->toolbar_hide_radiobutton), TRUE);
+	gtk_toggle_button_set_active (
+		GTK_TOGGLE_BUTTON (dlg->priv->toolbar_show_checkbutton), gedit_settings->toolbar_visible);
 
 	switch (gedit_settings->toolbar_buttons_style)
 	{
@@ -613,7 +637,7 @@ gedit_preferences_dialog_setup_toolbar_page (GeditPreferencesDialog *dlg, GladeX
 }
 
 static void 
-gedit_preferences_dialog_toolbar_show_radiobutton_toggled (GtkToggleButton *show_button,
+gedit_preferences_dialog_toolbar_show_checkbutton_toggled (GtkToggleButton *show_button,
 							 GeditPreferencesDialog *dlg)
 {
 	gedit_debug (DEBUG_PREFS, "");
@@ -630,29 +654,43 @@ gedit_preferences_dialog_toolbar_show_radiobutton_toggled (GtkToggleButton *show
 	}
 }
 
+static void 
+gedit_preferences_dialog_statusbar_show_checkbutton_toggled (GtkToggleButton *show_button,
+							 GeditPreferencesDialog *dlg)
+{
+	gedit_debug (DEBUG_PREFS, "");
+
+	if (gtk_toggle_button_get_active (show_button))
+	{
+		gtk_widget_set_sensitive (dlg->priv->statusbar_cursor_position_checkbutton, TRUE);
+		gtk_widget_set_sensitive (dlg->priv->statusbar_overwrite_mode_checkbutton, TRUE);
+	}
+	else
+	{
+		gtk_widget_set_sensitive (dlg->priv->statusbar_cursor_position_checkbutton, FALSE);
+		gtk_widget_set_sensitive (dlg->priv->statusbar_overwrite_mode_checkbutton, FALSE);
+	}
+}
+
+
 static gboolean 
 gedit_preferences_dialog_setup_statusbar_page (GeditPreferencesDialog *dlg, GladeXML *gui)
 {
 	gedit_debug (DEBUG_PREFS, "");
 
-	dlg->priv->statusbar_show_radiobutton = glade_xml_get_widget (gui, "statusbar_show_radiobutton");
-	dlg->priv->statusbar_hide_radiobutton = glade_xml_get_widget (gui, "statusbar_hide_radiobutton");
+	dlg->priv->statusbar_show_checkbutton = glade_xml_get_widget (gui, "statusbar_show_checkbutton");
 	dlg->priv->statusbar_cursor_position_checkbutton = glade_xml_get_widget (gui, 
 								"statusbar_cursor_position_checkbutton");
 	dlg->priv->statusbar_overwrite_mode_checkbutton = glade_xml_get_widget (gui, 
 								"statusbar_overwrite_mode_checkbutton");
 
-	g_return_val_if_fail (dlg->priv->statusbar_show_radiobutton, FALSE);
-	g_return_val_if_fail (dlg->priv->statusbar_hide_radiobutton, FALSE);
+	g_return_val_if_fail (dlg->priv->statusbar_show_checkbutton, FALSE);
 	g_return_val_if_fail (dlg->priv->statusbar_cursor_position_checkbutton, FALSE);
 	g_return_val_if_fail (dlg->priv->statusbar_overwrite_mode_checkbutton, FALSE);
 	
-	if (gedit_settings->statusbar_visible)
-		gtk_toggle_button_set_active (
-				GTK_TOGGLE_BUTTON (dlg->priv->statusbar_show_radiobutton), TRUE);
-	else
-		gtk_toggle_button_set_active (
-				GTK_TOGGLE_BUTTON (dlg->priv->statusbar_hide_radiobutton), TRUE);
+	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (
+				      dlg->priv->statusbar_show_checkbutton), 
+				      gedit_settings->statusbar_visible);
 
 	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (
 				      dlg->priv->statusbar_cursor_position_checkbutton),	
@@ -661,9 +699,19 @@ gedit_preferences_dialog_setup_statusbar_page (GeditPreferencesDialog *dlg, Glad
 	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (
 				      dlg->priv->statusbar_overwrite_mode_checkbutton),
 				      gedit_settings->statusbar_view_overwrite_mode);
+
+	if (!gedit_settings->statusbar_visible)
+	{
+		gtk_widget_set_sensitive (dlg->priv->statusbar_cursor_position_checkbutton, FALSE);
+		gtk_widget_set_sensitive (dlg->priv->statusbar_overwrite_mode_checkbutton, FALSE);
+	}
+
+	g_signal_connect (G_OBJECT (dlg->priv->statusbar_show_checkbutton), "toggled", 
+			G_CALLBACK (gedit_preferences_dialog_statusbar_show_checkbutton_toggled), dlg);
+
 	return TRUE;
 }
-
+#endif
 #ifdef DEBUG_MDI_PREFS
 
 static void
@@ -1070,16 +1118,17 @@ gedit_preferences_dialog_setup_line_numbers_page (GeditPreferencesDialog *dlg, G
 gboolean 
 gedit_preferences_dialog_update_settings (GeditPreferencesDialog *dlg)
 {
+#if 0
 	GeditPreferences old_prefs;
+#endif
 	const gchar* font;
 	guint16 dummy;
 
 	gedit_debug (DEBUG_PREFS, "");
-	
+#if 0		
 	old_prefs = *gedit_settings;
-	
 	/* Get data from toolbar page */
-	if (!gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (dlg->priv->toolbar_show_radiobutton)))
+	if (!gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (dlg->priv->toolbar_show_checkbutton)))
 		gedit_settings->toolbar_visible = FALSE;
 	else
 	{
@@ -1103,10 +1152,9 @@ gedit_preferences_dialog_update_settings (GeditPreferencesDialog *dlg)
 	}
 
 	/* Get data from status bar page */
-	if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (dlg->priv->statusbar_show_radiobutton)))
-		gedit_settings->statusbar_visible = TRUE;
-	else
-		gedit_settings->statusbar_visible = FALSE;
+	gedit_settings->statusbar_visible =
+		gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (
+					dlg->priv->statusbar_show_checkbutton));
 
 	gedit_settings->statusbar_view_cursor_position = 
 		gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (
@@ -1115,7 +1163,7 @@ gedit_preferences_dialog_update_settings (GeditPreferencesDialog *dlg)
 	gedit_settings->statusbar_view_overwrite_mode = 
 		gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (
 					dlg->priv->statusbar_overwrite_mode_checkbutton));
-		
+#endif		
 	/* Get data from undo page */
 	if (!gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (dlg->priv->undo_checkbutton)))
 		gedit_settings->undo_levels = 0;
@@ -1240,10 +1288,11 @@ gedit_preferences_dialog_update_settings (GeditPreferencesDialog *dlg)
 		gtk_spin_button_get_value (GTK_SPIN_BUTTON (dlg->priv->tabs_width_spinbutton));
 
 	return TRUE;
-	
+#if 0	
 error:
 	*gedit_settings = old_prefs;
 	g_return_val_if_fail (FALSE, FALSE);
+#endif
 }
 
 	
