@@ -35,7 +35,6 @@
 #include <gtk/gtkwidget.h>
 #include <gtk/gtkdialog.h>
 #include <gtk/gtktextiter.h>
-#include <atk/atk.h>
 
 #define GTK_TEXT_SEARCH_CASE_INSENSITIVE (1 << 7)
 
@@ -45,10 +44,10 @@ void	gedit_utils_flash_va  (gchar *format, ...);
 gboolean gedit_utils_is_uri_read_only (const gchar* uri);
 gboolean gedit_utils_uri_has_file_scheme (const gchar *uri);
 
-GtkWidget *gedit_button_new_with_stock_image (const gchar* text, 
+GtkWidget* gedit_button_new_with_stock_image (const gchar* text, 
 					      const gchar* stock_id);
 
-GtkWidget *gedit_dialog_add_button (GtkDialog *dialog, 
+GtkWidget* gedit_dialog_add_button (GtkDialog *dialog, 
 				    const gchar* text, 
 				    const gchar* stock_id, 
 				    gint response_id);
@@ -72,26 +71,7 @@ void gedit_utils_error_reporting_saving_file  (const gchar *uri,
 void gedit_utils_error_reporting_reverting_file (const gchar *uri, 
 					       GError *error,
 					       GtkWindow *parent);
-void gedit_utils_error_reporting_creating_file (const gchar *uri,
-						gint error_code,
-						GtkWindow *parent);
 
-gboolean g_utf8_caselessnmatch (const char *s1, const char *s2, gssize n1, gssize n2);
-
-void gedit_utils_set_atk_name_description (GtkWidget *widget, const gchar *name,
-						const gchar *description);
-void gedit_utils_set_atk_relation (GtkWidget *obj1, GtkWidget *obj2,
-						AtkRelationType rel_type);
-
-gboolean gedit_utils_uri_exists (const gchar* text_uri);
-
-gchar *gedit_utils_convert_search_text (const gchar *text);
-
-gboolean gedit_utils_create_empty_file (const gchar *uri);
-
-gchar *gedit_utils_get_stdin (void);
-gchar *gedit_utils_convert_to_utf8 (const gchar *content,
-				    gchar **encoding);
 
 #endif /* __GEDIT_UTILS_H__ */
 
